@@ -227,9 +227,17 @@ ASTNode NonMemberBVConstEvaluator(STPMgr* _bm, const Kind k,
     }
     case BVXOR:
     {
-      assert(2 == number_of_children);
+      assert(1 <= number_of_children);
+
       output = CONSTANTBV::BitVector_Create(inputwidth, true);
-      CONSTANTBV::Set_ExclusiveOr(output, tmp0, tmp1);
+
+      for (ASTVec::iterator it = children.begin(), itend = children.end();
+           it != itend; it++)
+      {
+        CBV kk = (*it).GetBVConst();
+        CONSTANTBV::Set_ExclusiveOr(output, output, kk);
+      }
+
       OutputNode = _bm->CreateBVConst(output, outputwidth);
       break;
     }
@@ -543,25 +551,8 @@ ASTNode NonMemberBVConstEvaluator(STPMgr* _bm, const Kind k,
             CONSTANTBV::BitVector_Div_Pos(quotient, tmp0, tmp1, remainder);
         CONSTANTBV::BitVector_Destroy(tmp0);
 
-        if (0 != e)
-        {
-          CONSTANTBV::BitVector_Destroy(quotient);
-          CONSTANTBV::BitVector_Destroy(remainder);
-          // error printing
-          if (_bm->counterexample_checking_during_refinement)
-          {
-            output = CONSTANTBV::BitVector_Create(inputwidth, true);
-            OutputNode = _bm->CreateBVConst(output, outputwidth);
-            //  CONSTANTBV::BitVector_Destroy(output);
-            break;
-          }
-          else
-          {
-            BVConstEvaluatorError(e);
-          }
-        }
+        assert (0 == e);
 
-        // FIXME Not very standard in the current scheme
         if (BVDIV == k)
         {
           OutputNode = _bm->CreateBVConst(quotient, outputwidth);
@@ -820,18 +811,4 @@ ASTNode NonMemberBVConstEvaluator(STPMgr* mgr, const ASTNode& t)
                                    t.GetValueWidth());
 }
 
-ASTNode Simplifier::BVConstEvaluator(const ASTNode& t)
-{
-  if (t.isConstant())
-    return t;
-
-  ASTNode OutputNode;
-
-  if (InsideSubstitutionMap(t, OutputNode))
-    return OutputNode;
-
-  OutputNode = NonMemberBVConstEvaluator(_bm, t);
-  UpdateSolverMap(t, OutputNode);
-  return OutputNode;
-}
 } // end of namespace stp
