@@ -43,7 +43,7 @@ THE SOFTWARE.
 #include "stp/Printer/printers.h"
 
 #include "stp/AST/AST.h"
-#include "stp/AST/NodeFactory/TypeChecker.h"
+#include "stp/NodeFactory/TypeChecker.h"
 #include "stp/STPManager/STP.h"
 #include "stp/STPManager/STPManager.h"
 #include "stp/Sat/MinisatCore.h"
@@ -56,9 +56,9 @@ THE SOFTWARE.
 #include "rewrite_rule.h"
 #include "rewrite_system.h"
 
-#include "stp/ToSat/AIG/BBNodeManagerAIG.h"
-#include "stp/ToSat/AIG/ToCNFAIG.h"
-#include "stp/ToSat/AIG/ToSATAIG.h"
+#include "stp/ToSat/BBNodeManagerAIG.h"
+#include "stp/ToSat/ToCNFAIG.h"
+#include "stp/ToSat/ToSATAIG.h"
 #include "stp/ToSat/BitBlaster.h"
 
 #include <fstream>
@@ -753,13 +753,7 @@ void startup()
 
   mgr = new stp::STPMgr();
   stp::GlobalParserBM = mgr;
-
-  simp = new Simplifier(mgr);
-  ArrayTransformer* at = new ArrayTransformer(mgr, simp);
-  AbsRefine_CounterExample* abs = new AbsRefine_CounterExample(mgr, simp, at);
-  ToSATAIG* tosat = new ToSATAIG(mgr, at);
-
-  GlobalSTP = new STP(mgr, simp, at, tosat, abs);
+  GlobalSTP = new STP(mgr);
 
   mgr->defaultNodeFactory =
       new SimplifyingNodeFactory(*mgr->hashingNodeFactory, *mgr);
@@ -1223,7 +1217,7 @@ void rule_to_string(const ASTNode& n, ASTNodeString& names, string& current,
   for (size_t i = 0; i < n.Degree(); i++)
   {
     char t[1000];
-    sprintf(t, "%s[%d]", current.c_str(), i);
+    sprintf(t, "%s[%zu]", current.c_str(), i);
     string s(t);
     rule_to_string(n[i], names, s, sofar);
   }
@@ -1242,7 +1236,7 @@ string containsNode(const ASTNode& n, const ASTNode& hunting, string& current)
   for (size_t i = 0; i < n.Degree(); i++)
   {
     char t[1000];
-    sprintf(t, "%s[%d]", current.c_str(), i);
+    sprintf(t, "%s[%zu]", current.c_str(), i);
     string s(t);
     string r = containsNode(n[i], hunting, s);
     if (r != "")
